@@ -1,5 +1,5 @@
 (* ocamlgsl - OCaml interface to GSL                        *)
-(* Copyright () 2002 - Olivier Andrieu                     *)
+(* Copyright (©) 2002-2005 - Olivier Andrieu                *)
 (* distributed under the terms of the GPL version 2         *)
 
 type t
@@ -32,15 +32,27 @@ external _eval_n : t -> int -> float -> float
 external _eval_n_err : t -> int -> float -> Gsl_fun.result
     = "ml_gsl_cheb_eval_n_err"
 
-let eval cs ?order x =
-  match order with
-  | None -> _eval cs x
-  | Some o -> _eval_n cs o x
+external _eval_mode : t -> float -> Gsl_fun.mode -> float
+    = "ml_gsl_cheb_eval_mode"
 
-let eval_err cs ?order x =
-  match order with
-  | None -> _eval_err cs x
-  | Some o -> _eval_n_err cs o x
+external _eval_mode_e : t -> float -> Gsl_fun.mode -> Gsl_fun.result
+    = "ml_gsl_cheb_eval_mode_e"
+
+let eval cs ?mode ?order x =
+  match mode with
+  | Some m -> _eval_mode cs x m
+  | None -> 
+      match order with
+      | None -> _eval cs x
+      | Some o -> _eval_n cs o x
+
+let eval_err cs ?mode ?order x =
+  match mode with
+  | Some m -> _eval_mode_e cs x m
+  | None -> 
+      match order with
+      | None -> _eval_err cs x
+      | Some o -> _eval_n_err cs o x
 
 external calc_deriv : t -> t -> unit
     = "ml_gsl_cheb_calc_deriv"
