@@ -1,5 +1,5 @@
 (* ocamlgsl - OCaml interface to GSL                        *)
-(* Copyright () 2002 - Olivier Andrieu                     *)
+(* Copyright (©) 2002-2005 - Olivier Andrieu                *)
 (* distributed under the terms of the GPL version 2         *)
 
 type t
@@ -12,8 +12,8 @@ external order : t -> int
 external init : t -> Gsl_fun.gsl_fun -> a:float -> b:float -> unit
     = "ml_gsl_cheb_init"
 
-val eval     : t -> ?order:int -> float -> float
-val eval_err : t -> ?order:int -> float -> Gsl_fun.result
+val eval     : t -> ?mode:Gsl_fun.mode -> ?order:int -> float -> float
+val eval_err : t -> ?mode:Gsl_fun.mode -> ?order:int -> float -> Gsl_fun.result
 
 val deriv : t -> t
 val integ : t -> t
