@@ -1,5 +1,5 @@
 /* ocamlgsl - OCaml interface to GSL                        */
-/* Copyright () 2002 - Olivier Andrieu                     */
+/* Copyright (©) 2002-2005 - Olivier Andrieu                */
 /* distributed under the terms of the GPL version 2         */
 
 #include <caml/memory.h>
@@ -14,12 +14,12 @@
 ML1_alloc(gsl_cheb_alloc, Int_val, Abstract_ptr)
 ML1(gsl_cheb_free, CHEB_VAL, Unit)
 
-value ml_gsl_cheb_order(value c)
+CAMLprim value ml_gsl_cheb_order(value c)
 {
   return Val_int(CHEB_VAL(c)->order);
 }
 
-value ml_gsl_cheb_init(value cs, value f, value a, value b)
+CAMLprim value ml_gsl_cheb_init(value cs, value f, value a, value b)
 {
   CAMLparam1(f);
   GSLFUN_CLOSURE(gf, f);
@@ -29,7 +29,7 @@ value ml_gsl_cheb_init(value cs, value f, value a, value b)
 
 ML2(gsl_cheb_eval, CHEB_VAL, Double_val, copy_double)
 
-value ml_gsl_cheb_eval_err(value cheb, value x)
+CAMLprim value ml_gsl_cheb_eval_err(value cheb, value x)
 {
   double res,err;
   gsl_cheb_eval_err(CHEB_VAL(cheb), Double_val(x), &res, &err);
@@ -38,7 +38,7 @@ value ml_gsl_cheb_eval_err(value cheb, value x)
 
 ML3(gsl_cheb_eval_n, CHEB_VAL, Int_val, Double_val, copy_double)
 
-value ml_gsl_cheb_eval_n_err(value cheb, value order, value x)
+CAMLprim value ml_gsl_cheb_eval_n_err(value cheb, value order, value x)
 {
   double res,err;
   gsl_cheb_eval_n_err(CHEB_VAL(cheb), Int_val(order),
@@ -46,5 +46,15 @@ value ml_gsl_cheb_eval_n_err(value cheb, value order, value x)
   return copy_two_double_arr(res, err);
 }
 
+ML3(gsl_cheb_eval_mode, CHEB_VAL, Double_val, Int_val, copy_double)
+
+CAMLprim value ml_gsl_cheb_eval_mode_e(value cheb, value x, value mode)
+{
+  double res,err;
+  gsl_cheb_eval_mode_e(CHEB_VAL(cheb), Double_val(x), Int_val(mode),
+		       &res, &err);
+  return copy_two_double_arr(res, err);
+}
+
 ML2(gsl_cheb_calc_deriv, CHEB_VAL, CHEB_VAL, Unit)
 ML2(gsl_cheb_calc_integ, CHEB_VAL, CHEB_VAL, Unit)
