@@ -1,5 +1,5 @@
 /* ocamlgsl - OCaml interface to GSL                        */
-/* Copyright () 2002 - Olivier Andrieu                     */
+/* Copyright (©) 2002-2005 - Olivier Andrieu                */
 /* distributed under the terms of the GPL version 2         */
 
 #include <caml/fail.h>
@@ -21,9 +21,9 @@ enum mlgsl_fft_array_layout {
 } ;
 
 static void check_layout(value fft_arr, 
-				 enum mlgsl_fft_array_layout layout)
+			 enum mlgsl_fft_array_layout layout)
 {
-  static value *layout_exn = NULL;
+  static value *layout_exn;
   if(Int_val(Field(fft_arr, 0)) != layout) { 
     if(!layout_exn) {
       layout_exn = caml_named_value("mlgsl_layout_exn");
@@ -65,7 +65,7 @@ ML1(gsl_fft_complex_wavetable_free, GSL_COMPLEX_WT, Unit)
 
 /* UNPACKING ROUTINES */
 
-value ml_gsl_fft_real_unpack(value stride, value r, value c)
+CAMLprim value ml_gsl_fft_real_unpack(value stride, value r, value c)
 {
   const size_t c_stride = Opt_arg(stride, Int_val, 1);
   const size_t n = Double_array_length(r);
@@ -73,7 +73,7 @@ value ml_gsl_fft_real_unpack(value stride, value r, value c)
   return Val_unit;
 }
 
-value ml_gsl_fft_halfcomplex_unpack(value stride, value hc, value c)
+CAMLprim value ml_gsl_fft_halfcomplex_unpack(value stride, value hc, value c)
 {
   const size_t c_stride = Opt_arg(stride, Int_val, 1);
   const size_t n = Double_array_length(hc);
@@ -82,7 +82,7 @@ value ml_gsl_fft_halfcomplex_unpack(value stride, value hc, value c)
   return Val_unit;
 }
 
-value ml_gsl_fft_halfcomplex_unpack_rad2(value stride, value hc, value c)
+CAMLprim value ml_gsl_fft_halfcomplex_unpack_rad2(value stride, value hc, value c)
 {
   const size_t c_stride = Opt_arg(stride, Int_val ,1);
   const size_t n = Double_array_length(hc);
@@ -95,7 +95,7 @@ value ml_gsl_fft_halfcomplex_unpack_rad2(value stride, value hc, value c)
 
 /* REAL AND HALFCOMPLEX MIXED-RADIX FFT */
 
-value ml_gsl_fft_real_transform(value stride, value fft_arr, value wt, value ws)
+CAMLprim value ml_gsl_fft_real_transform(value stride, value fft_arr, value wt, value ws)
 {
   value data = Field(fft_arr, 1);
   const size_t c_stride = Opt_arg(stride, Int_val, 1);
@@ -109,7 +109,7 @@ value ml_gsl_fft_real_transform(value stride, value fft_arr, value wt, value ws)
   return Val_unit;
 }
 
-value ml_gsl_fft_halfcomplex_transform(value stride, value fft_arr, 
+CAMLprim value ml_gsl_fft_halfcomplex_transform(value stride, value fft_arr, 
 				       value wt, value ws)
 {
   value data = Field(fft_arr, 1);
@@ -124,7 +124,7 @@ value ml_gsl_fft_halfcomplex_transform(value stride, value fft_arr,
   return Val_unit;
 }
 
-value ml_gsl_fft_halfcomplex_backward(value stride, value fft_arr,
+CAMLprim value ml_gsl_fft_halfcomplex_backward(value stride, value fft_arr,
 				      value wt, value ws)
 {
   value data = Field(fft_arr, 1);
@@ -140,7 +140,7 @@ value ml_gsl_fft_halfcomplex_backward(value stride, value fft_arr,
   return Val_unit;
 }
 
-value ml_gsl_fft_halfcomplex_inverse(value stride, value fft_arr,
+CAMLprim value ml_gsl_fft_halfcomplex_inverse(value stride, value fft_arr,
 				     value wt, value ws)
 {
   value data = Field(fft_arr, 1);
@@ -160,7 +160,7 @@ value ml_gsl_fft_halfcomplex_inverse(value stride, value fft_arr,
 
 /* REAL AND HALFCOMPLEX RADIX2 FFT */
 
-value ml_gsl_fft_real_radix2_transform(value stride, value fft_arr)
+CAMLprim value ml_gsl_fft_real_radix2_transform(value stride, value fft_arr)
 {
   value data = Field(fft_arr, 1);
   size_t N = Double_array_length(data);
@@ -173,7 +173,7 @@ value ml_gsl_fft_real_radix2_transform(value stride, value fft_arr)
   return Val_unit;
 }
 
-value ml_gsl_fft_halfcomplex_radix2_transform(value stride, value fft_arr)
+CAMLprim value ml_gsl_fft_halfcomplex_radix2_transform(value stride, value fft_arr)
 {
   value data = Field(fft_arr, 1);
   size_t N = Double_array_length(data);
@@ -185,7 +185,7 @@ value ml_gsl_fft_halfcomplex_radix2_transform(value stride, value fft_arr)
   return Val_unit;
 }
 
-value ml_gsl_fft_halfcomplex_radix2_backward(value stride, value fft_arr)
+CAMLprim value ml_gsl_fft_halfcomplex_radix2_backward(value stride, value fft_arr)
 {
   value data = Field(fft_arr, 1);
   size_t N = Double_array_length(data);
@@ -199,7 +199,7 @@ value ml_gsl_fft_halfcomplex_radix2_backward(value stride, value fft_arr)
   return Val_unit;
 }
 
-value ml_gsl_fft_halfcomplex_radix2_inverse(value stride, value fft_arr)
+CAMLprim value ml_gsl_fft_halfcomplex_radix2_inverse(value stride, value fft_arr)
 {
   value data = Field(fft_arr, 1);
   size_t N = Double_array_length(data);
@@ -216,7 +216,7 @@ value ml_gsl_fft_halfcomplex_radix2_inverse(value stride, value fft_arr)
 
 /* COMPLEX RADIX-2 FFT */
 
-value ml_gsl_fft_complex_rad2_forward(value dif, value stride, value data)
+CAMLprim value ml_gsl_fft_complex_rad2_forward(value dif, value stride, value data)
 {
   size_t N = Double_array_length(data);
   size_t c_stride = Opt_arg(stride, Int_val, 1);
@@ -230,7 +230,7 @@ value ml_gsl_fft_complex_rad2_forward(value dif, value stride, value data)
   return Val_unit;
 }
 
-value ml_gsl_fft_complex_rad2_transform(value dif, value stride, 
+CAMLprim value ml_gsl_fft_complex_rad2_transform(value dif, value stride, 
 					value data, value sign)
 {
   size_t N = Double_array_length(data);
@@ -248,7 +248,7 @@ value ml_gsl_fft_complex_rad2_transform(value dif, value stride,
   return Val_unit;
 }
 
-value ml_gsl_fft_complex_rad2_backward(value dif, value stride, value data)
+CAMLprim value ml_gsl_fft_complex_rad2_backward(value dif, value stride, value data)
 {
   size_t N = Double_array_length(data);
   size_t c_stride = Opt_arg(stride, Int_val, 1);
@@ -262,7 +262,7 @@ value ml_gsl_fft_complex_rad2_backward(value dif, value stride, value data)
   return Val_unit;
 }
 
-value ml_gsl_fft_complex_rad2_inverse(value dif, value stride, value data)
+CAMLprim value ml_gsl_fft_complex_rad2_inverse(value dif, value stride, value data)
 {
   size_t N = Double_array_length(data);
   size_t c_stride = Opt_arg(stride, Int_val, 1);
@@ -281,7 +281,7 @@ value ml_gsl_fft_complex_rad2_inverse(value dif, value stride, value data)
 
 /* COMPLEX MIXED RADIX FFT */
 
-value ml_gsl_fft_complex_forward(value stride, value data, value wt, value ws)
+CAMLprim value ml_gsl_fft_complex_forward(value stride, value data, value wt, value ws)
 {
   const size_t c_stride = Opt_arg(stride, Int_val, 1);
   const size_t n = Double_array_length(data) / 2;
@@ -291,7 +291,7 @@ value ml_gsl_fft_complex_forward(value stride, value data, value wt, value ws)
   return Val_unit;
 }
 
-value ml_gsl_fft_complex_transform(value stride, value data, 
+CAMLprim value ml_gsl_fft_complex_transform(value stride, value data, 
 				   value wt, value ws, value sign)
 {
   const size_t c_stride = Opt_arg(stride, Int_val, 1);
@@ -305,7 +305,7 @@ value ml_gsl_fft_complex_transform(value stride, value data,
   return Val_unit;
 }
 
-value ml_gsl_fft_complex_backward(value stride, value data, 
+CAMLprim value ml_gsl_fft_complex_backward(value stride, value data, 
 				  value wt, value ws)
 {
   const size_t c_stride = Opt_arg(stride, Int_val, 1);
@@ -318,7 +318,7 @@ value ml_gsl_fft_complex_backward(value stride, value data,
   return Val_unit;
 }
 
-value ml_gsl_fft_complex_inverse(value stride, value data,
+CAMLprim value ml_gsl_fft_complex_inverse(value stride, value data,
 				 value wt, value ws)
 {
   const size_t c_stride = Opt_arg(stride, Int_val ,1);
