@@ -1,5 +1,5 @@
 /* ocamlgsl - OCaml interface to GSL                        */
-/* Copyright () 2002 - Olivier Andrieu                     */
+/* Copyright (©) 2002-2005 - Olivier Andrieu                */
 /* distributed under the terms of the GPL version 2         */
 
 
@@ -58,7 +58,7 @@ static int ml_gsl_odeiv_jacobian(double t, const double y[],
   return GSL_SUCCESS;
 }
 
-value ml_gsl_odeiv_alloc_system(value func, value ojac, value dim)
+CAMLprim value ml_gsl_odeiv_alloc_system(value func, value ojac, value dim)
 {
   const int barr_flags = BIGARRAY_FLOAT64 | BIGARRAY_C_LAYOUT | BIGARRAY_EXTERNAL;
   struct mlgsl_odeiv_params *p;
@@ -88,7 +88,7 @@ value ml_gsl_odeiv_alloc_system(value func, value ojac, value dim)
 
 #define ODEIV_SYSTEM_VAL(v) ((gsl_odeiv_system *)Field((v), 0))
 
-value ml_gsl_odeiv_free_system(value vsyst)
+CAMLprim value ml_gsl_odeiv_free_system(value vsyst)
 {
   gsl_odeiv_system *syst = ODEIV_SYSTEM_VAL(vsyst);
   struct mlgsl_odeiv_params *p = syst->params;
@@ -103,12 +103,13 @@ value ml_gsl_odeiv_free_system(value vsyst)
 }
 
 
-value ml_gsl_odeiv_step_alloc(value step_type, value dim)
+CAMLprim value ml_gsl_odeiv_step_alloc(value step_type, value dim)
 {
   const gsl_odeiv_step_type *steppers[] = {
     gsl_odeiv_step_rk2, gsl_odeiv_step_rk4,
     gsl_odeiv_step_rkf45, gsl_odeiv_step_rkck,
     gsl_odeiv_step_rk8pd, gsl_odeiv_step_rk2imp,
+    gsl_odeiv_step_rk2simp,
     gsl_odeiv_step_rk4imp, gsl_odeiv_step_bsimp,
     gsl_odeiv_step_gear1, gsl_odeiv_step_gear2, };
   gsl_odeiv_step *step = gsl_odeiv_step_alloc(steppers[ Int_val(step_type) ],
@@ -125,7 +126,7 @@ ML1(gsl_odeiv_step_reset, ODEIV_STEP_VAL, Unit)
 ML1(gsl_odeiv_step_name, ODEIV_STEP_VAL, copy_string)
 ML1(gsl_odeiv_step_order, ODEIV_STEP_VAL, Val_int)
 
-value ml_gsl_odeiv_step_apply(value step, value t, value h, value y,
+CAMLprim value ml_gsl_odeiv_step_apply(value step, value t, value h, value y,
 			      value yerr, value odydt_in, value odydt_out, 
 			      value syst)
 {
@@ -158,13 +159,13 @@ value ml_gsl_odeiv_step_apply(value step, value t, value h, value y,
   CAMLreturn(Val_unit);
 }
 
-value ml_gsl_odeiv_step_apply_bc(value argv[], int argc)
+CAMLprim value ml_gsl_odeiv_step_apply_bc(value argv[], int argc)
 {
   return ml_gsl_odeiv_step_apply(argv[0], argv[1], argv[2], argv[3],
 				 argv[4], argv[5], argv[6], argv[7]);
 }
 
-value ml_gsl_odeiv_control_standard_new(value eps_abs, value eps_rel,
+CAMLprim value ml_gsl_odeiv_control_standard_new(value eps_abs, value eps_rel,
 					value a_y, value a_dydt)
 {
   gsl_odeiv_control *c = 
@@ -175,7 +176,7 @@ value ml_gsl_odeiv_control_standard_new(value eps_abs, value eps_rel,
   return res;
 }
 
-value ml_gsl_odeiv_control_y_new(value eps_abs, value eps_rel)
+CAMLprim value ml_gsl_odeiv_control_y_new(value eps_abs, value eps_rel)
 {
   gsl_odeiv_control *c = 
     gsl_odeiv_control_y_new(Double_val(eps_abs), Double_val(eps_rel));
@@ -184,7 +185,7 @@ value ml_gsl_odeiv_control_y_new(value eps_abs, value eps_rel)
   return res;
 }
 
-value ml_gsl_odeiv_control_yp_new(value eps_abs, value eps_rel)
+CAMLprim value ml_gsl_odeiv_control_yp_new(value eps_abs, value eps_rel)
 {
   gsl_odeiv_control *c = 
     gsl_odeiv_control_yp_new(Double_val(eps_abs), Double_val(eps_rel));
@@ -193,7 +194,7 @@ value ml_gsl_odeiv_control_yp_new(value eps_abs, value eps_rel)
   return res;
 }
 
-value ml_gsl_odeiv_control_scaled_new(value eps_abs, value eps_rel,
+CAMLprim value ml_gsl_odeiv_control_scaled_new(value eps_abs, value eps_rel,
 				      value a_y, value a_dydt, value scale_abs)
 {
   gsl_odeiv_control *c = 
@@ -211,7 +212,7 @@ value ml_gsl_odeiv_control_scaled_new(value eps_abs, value eps_rel,
 ML1(gsl_odeiv_control_free, ODEIV_CONTROL_VAL, Unit)
 ML1(gsl_odeiv_control_name, ODEIV_CONTROL_VAL, copy_string)
 
-value ml_gsl_odeiv_control_hadjust(value c, value s, value y0,
+CAMLprim value ml_gsl_odeiv_control_hadjust(value c, value s, value y0,
 				   value yerr, value dydt, value h)
 {
   double c_h = Double_val(h);
@@ -230,13 +231,13 @@ value ml_gsl_odeiv_control_hadjust(value c, value s, value y0,
   }
 }
 
-value ml_gsl_odeiv_control_hadjust_bc(value *argv, int argc)
+CAMLprim value ml_gsl_odeiv_control_hadjust_bc(value *argv, int argc)
 {
   return ml_gsl_odeiv_control_hadjust(argv[0], argv[1], argv[2], 
 				      argv[3], argv[4], argv[5]);
 }
 
-value ml_gsl_odeiv_evolve_alloc(value dim)
+CAMLprim value ml_gsl_odeiv_evolve_alloc(value dim)
 {
   gsl_odeiv_evolve *e = gsl_odeiv_evolve_alloc(Int_val(dim));
   value res;
@@ -249,7 +250,7 @@ value ml_gsl_odeiv_evolve_alloc(value dim)
 ML1(gsl_odeiv_evolve_free, ODEIV_EVOLVE_VAL, Unit)
 ML1(gsl_odeiv_evolve_reset, ODEIV_EVOLVE_VAL, Unit)
   
-value ml_gsl_odeiv_evolve_apply(value e, value c, value s, 
+CAMLprim value ml_gsl_odeiv_evolve_apply(value e, value c, value s, 
 				value syst, value t, value t1, 
 				value h, value y)
 {
@@ -267,7 +268,7 @@ value ml_gsl_odeiv_evolve_apply(value e, value c, value s,
   CAMLreturn(copy_two_double(t_c, h_c));
 }
 
-value ml_gsl_odeiv_evolve_apply_bc(value *argv, int argc)
+CAMLprim value ml_gsl_odeiv_evolve_apply_bc(value *argv, int argc)
 {
   return ml_gsl_odeiv_evolve_apply(argv[0], argv[1], argv[2], argv[3],
 				   argv[4], argv[5], argv[6], argv[7]);
